DistMA
======

.. currentmodule:: pykeen.models

.. autoclass:: DistMA
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DistMA.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
